"""
error tags
"""
je_auto_control_error = "Auto control error"
"""
keyboard tags
"""
keyboard_error = "Auto control keyboard error"
keyboard_press_key = "keyboard press key error"
keyboard_release_key = "keyboard release key error"
keyboard_type_key = "keyboard type key error"
keyboard_write = "keyboard write error"
keyboard_write_cant_find = "keyboard write error can't find key"
keyboard_hotkey = "keyboard hotkey error"
"""
mouse tags
"""
mouse_error = "Auto control mouse error"
mouse_get_position = "mouse get position error"
mouse_set_position = "mouse set position error"
mouse_press_mouse = "mouse press mouse error"
mouse_release_mouse = "mouse release key error"
mouse_click_mouse = "mouse click mouse error"
mouse_scroll = "mouse scroll error"
"""
screen tags
"""
screen_error = "Auto control screen error"
screen_get_size = "screen get size error"
screen_screenshot = "screen screenshot error"
"""
table tags
"""
table_cant_find_key = "can't find key error"
"""
image tags
"""
cant_find_image = "can't find image"
find_image_error_variable = "variable error"
